@@ -1,6 +1,6 @@
 #!/bin/sh
 
-for l in en fr de ca es it nl ; do
+for l in en; do
   echo "=== Screenshots for $l ==="
   env LANGUAGE="$l" LANG="$l" ./get_images.sh "$1"
   mkdir "../img/generated_$l"
@@ -8,4 +8,3 @@ for l in en fr de ca es it nl ; do
     mv "$p" "../img/generated_$l"
   done
 done
-
